@@ -8,7 +8,7 @@
 
 from __future__ import annotations
 
-from typing import Dict, Optional, Tuple, List
+from typing import Dict, Optional, Tuple, List, Union
 from keras.layers import Dense
 from keras import activations
 from keras import Model
@@ -230,7 +230,6 @@ class TensorFlowModel(ModelInterface):
             layer.set_weights([np.random.permutation(w) for w in weights])
             yield layer.name, random_layer_model
 
-
     @cachedmethod(operator.attrgetter("cache"))
     def _build_hidden_representation_model(
         self, layer_names: Tuple, layer_indices: Tuple
@@ -263,6 +262,54 @@ class TensorFlowModel(ModelInterface):
         hidden_representation_model = Model(self.model.input, outputs_of_interest)
         return hidden_representation_model
 
+    @cachedmethod(operator.attrgetter("cache"))
+    def add_mean_shift_to_first_layer(
+        self,
+        input_shift: Union[int, float],
+        shape: tuple,
+    ):
+        """
+        Consider the first layer neuron before non-linearity: z = w^T * x1 + b1. We update
+        the bias b1 to b2:= b1 - w^T * m (= 2*b1 - (w^T * m + b1)). The operation is necessary
+        for Input Invariance metric.
+
+
+        Parameters
+        ----------
+        input_shift: Union[int, float]
+            Shift to be applied.
+        shape: tuple
+            Model input shape, ndim = 4.
+
+        Returns
+        -------
+        random_layer_model: Model
+            The resulting model with a shifted first layer.
+        """
+        original_parameters = self.state_dict()
+        new_model = clone_model(self.model)
+        new_model.set_weights(original_parameters)
+
+        module = new_model.layers[0]
+        tmp_model = Model(
+            inputs=[new_model.input], outputs=[new_model.layers[0].output]
+        )
+
+        delta = np.zeros(shape=shape)
+        delta.fill(input_shift)
+        fw = tmp_model(delta)[0]
+
+        weights = module.get_weights()
+        bias = weights[1]
+
+        for i in range(len(bias)):
+            if self.channel_first:
+                weights[1][i] = 2 * bias[i] - np.unique(fw[i])[0]
+            else:
+                weights[1][i] = 2 * bias[i] - np.unique(fw[..., i])[0]
+
+        module.set_weights(weights)
+        return new_model
 
     def get_hidden_representations(
         self,
@@ -328,4 +375,3 @@ class TensorFlowModel(ModelInterface):
             i.reshape((input_batch_size, -1)) for i in internal_representation
         ]
         return np.hstack(internal_representation)
-
