@@ -7,14 +7,15 @@
 # Quantus project URL: <https://github.com/understandable-machine-intelligence-lab/Quantus>.
 
 from typing import Any, Callable, Dict, List, Optional, Tuple
+
 import numpy as np
 from scipy.spatial.distance import cdist
 
-from ..base import Metric
-from ...helpers import warn_func
-from ...helpers import asserts
-from ...helpers.model_interface import ModelInterface
-from ...helpers.normalise_func import normalise_by_negative
+from quantus.helpers import asserts
+from quantus.helpers import warn
+from quantus.helpers.model.model_interface import ModelInterface
+from quantus.functions.normalise_func import normalise_by_max
+from quantus.metrics.base import Metric
 
 
 class Sufficiency(Metric):
@@ -31,8 +32,8 @@ class Sufficiency(Metric):
         the explanation and the explanations of the data point is under the user-defined threshold.
 
     References:
-         1) Sanjoy Dasgupta, Nave Frost, and Michal Moshkovitz. "Framework for Evaluating Faithfulness of Local
-            Explanations." arXiv preprint arXiv:2202.00734 (2022).
+         1) Sanjoy Dasgupta et al.: "Framework for Evaluating Faithfulness of Local
+            Explanations." ICML (2022): 4794-4815.
     """
 
     @asserts.attributes_check
@@ -45,7 +46,7 @@ class Sufficiency(Metric):
         normalise_func: Optional[Callable[[np.ndarray], np.ndarray]] = None,
         normalise_func_kwargs: Optional[Dict[str, Any]] = None,
         return_aggregate: bool = False,
-        aggregate_func: Optional[Callable] = np.mean,
+        aggregate_func: Callable = np.mean,
         default_plot_func: Optional[Callable] = None,
         disable_warnings: bool = False,
         display_progressbar: bool = False,
@@ -62,7 +63,7 @@ class Sufficiency(Metric):
             Indicates whether normalise operation is applied on the attribution, default=True.
         normalise_func: callable
             Attribution normalisation function applied in case normalise=True.
-            If normalise_func=None, the default value is used, default=normalise_by_negative.
+            If normalise_func=None, the default value is used, default=normalise_by_max.
         normalise_func_kwargs: dict
             Keyword arguments to be passed to normalise_func on call, default={}.
         perturb_func: callable
@@ -87,7 +88,7 @@ class Sufficiency(Metric):
             Keyword arguments.
         """
         if normalise_func is None:
-            normalise_func = normalise_by_negative
+            normalise_func = normalise_by_max
 
         super().__init__(
             abs=abs,
@@ -109,7 +110,7 @@ class Sufficiency(Metric):
 
         # Asserts and warnings.
         if not self.disable_warnings:
-            warn_func.warn_parameterisation(
+            warn.warn_parameterisation(
                 metric_name=self.__class__.__name__,
                 sensitive_params=(
                     "distance threshold that determines if images share an attribute 'threshold', "
@@ -128,13 +129,14 @@ class Sufficiency(Metric):
         y_batch: np.array,
         a_batch: Optional[np.ndarray] = None,
         s_batch: Optional[np.ndarray] = None,
-        custom_batch: Optional[np.ndarray] = None,
         channel_first: Optional[bool] = None,
         explain_func: Optional[Callable] = None,
-        explain_func_kwargs: Optional[Dict[str, Any]] = None,
-        model_predict_kwargs: Optional[Dict[str, Any]] = None,
-        softmax: bool = True,
+        explain_func_kwargs: Optional[Dict] = None,
+        model_predict_kwargs: Optional[Dict] = None,
+        softmax: Optional[bool] = True,
         device: Optional[str] = None,
+        batch_size: int = 64,
+        custom_batch: Optional[Any] = None,
         **kwargs,
     ) -> List[float]:
         """
@@ -148,7 +150,7 @@ class Sufficiency(Metric):
 
         Parameters
         ----------
-        model: Union[torch.nn.Module, tf.keras.Model]
+        model: torch.nn.Module, tf.keras.Model
             A torch or tensorflow model that is subject to explanation.
         x_batch: np.ndarray
             A np.ndarray which contains the input data that are explained.
@@ -172,9 +174,6 @@ class Sufficiency(Metric):
             This is used for this __call__ only and won't be saved as attribute. If None, self.softmax is used.
         device: string
             Indicated the device on which a torch.Tensor is or will be allocated: "cpu" or "gpu".
-        custom_batch: any
-            Any object that can be passed to the evaluation process.
-            Gives flexibility to the user to adapt for implementing their own metric.
         kwargs: optional
             Keyword arguments.
 
@@ -219,7 +218,7 @@ class Sufficiency(Metric):
             y_batch=y_batch,
             a_batch=a_batch,
             s_batch=s_batch,
-            custom_batch=custom_batch,
+            custom_batch=None,
             channel_first=channel_first,
             explain_func=explain_func,
             explain_func_kwargs=explain_func_kwargs,
@@ -231,22 +230,20 @@ class Sufficiency(Metric):
 
     def evaluate_instance(
         self,
-        i: int,
         model: ModelInterface,
         x: np.ndarray,
         y: np.ndarray,
         a: np.ndarray,
         s: np.ndarray,
-        c: Any,
-        p: Any,
+        i: int = None,
+        a_sim_vector: np.ndarray = None,
+        y_pred_classes: np.ndarray = None,
     ) -> float:
         """
         Evaluate instance gets model and data for a single instance as input and returns the evaluation result.
 
         Parameters
         ----------
-        i: integer
-            The evaluation instance.
         model: ModelInterface
             A ModelInteface that is subject to explanation.
         x: np.ndarray
@@ -257,10 +254,12 @@ class Sufficiency(Metric):
             The explanation to be evaluated on an instance-basis.
         s: np.ndarray
             The segmentation to be evaluated on an instance-basis.
-        c: any
+        i: int
+            The index of the current instance.
+        a_sim_vector: any
             The custom input to be evaluated on an instance-basis.
-        p: any
-            The custom preprocess input to be evaluated on an instance-basis.
+        y_pred_classes: np,ndarray
+            The class predictions of the complete input dataset.
 
         Returns
         -------
@@ -268,14 +267,11 @@ class Sufficiency(Metric):
             The evaluation results.
         """
 
-        # Unpack custom preprocess.
-        a_sim_vector = c
-
         # Metric logic.
-        pred_a = self.y_pred_classes[i]
+        pred_a = y_pred_classes[i]
         low_dist_a = np.argwhere(a_sim_vector == 1.0).flatten()
         low_dist_a = low_dist_a[low_dist_a != i]
-        pred_low_dist_a = self.y_pred_classes[low_dist_a]
+        pred_low_dist_a = y_pred_classes[low_dist_a]
 
         if len(low_dist_a) == 0:
             return 0
@@ -289,15 +285,13 @@ class Sufficiency(Metric):
         a_batch: Optional[np.ndarray],
         s_batch: np.ndarray,
         custom_batch: Optional[np.ndarray],
-    ) -> Tuple[
-        ModelInterface, np.ndarray, np.ndarray, np.ndarray, np.ndarray, Any, Any
-    ]:
+    ) -> Dict[str, Any]:
         """
         Implementation of custom_preprocess_batch.
 
         Parameters
         ----------
-        model: Union[torch.nn.Module, tf.keras.Model]
+        model: torch.nn.Module, tf.keras.Model
             A torch or tensorflow model e.g., torchvision.models that is subject to explanation.
         x_batch: np.ndarray
             A np.ndarray which contains the input data that are explained.
@@ -312,9 +306,8 @@ class Sufficiency(Metric):
 
         Returns
         -------
-        tuple
-            In addition to the x_batch, y_batch, a_batch, s_batch and custom_batch, returning a custom preprocess batch (custom_preprocess_batch).
-
+        dictionary[str, np.ndarray]
+            Output dictionary with 'a_sim_vector_batch' as and attributtion similarity matrix as value.
         """
 
         a_batch_flat = a_batch.reshape(a_batch.shape[0], -1)
@@ -328,17 +321,9 @@ class Sufficiency(Metric):
             x_batch, x_batch[0].shape, channel_first=True, batched=True
         )
 
-        self.y_pred_classes = np.argmax(model.predict(x_input), axis=1).flatten()
-
-        # Create the custom batch.
-        custom_preprocess_batch = a_sim_matrix
-
-        return (
-            model,
-            x_batch,
-            y_batch,
-            a_batch,
-            s_batch,
-            custom_batch,
-            custom_preprocess_batch,
-        )
+        y_pred_classes = np.argmax(model.predict(x_input), axis=1).flatten()
+        return {
+            "i_batch": np.arange(x_batch.shape[0]),
+            "a_sim_vector_batch": a_sim_matrix,
+            "y_pred_classes": y_pred_classes,
+        }
