@@ -2,6 +2,9 @@ from typing import Union, Optional, Dict
 
 import pytest
 from pytest_lazyfixture import lazy_fixture
+import numpy as np
+import torch
+import pickle
 
 from quantus.functions.explanation_func import explain
 from quantus.functions.mosaic_func import mosaic_creation
@@ -16,7 +19,6 @@ from quantus.metrics.localisation import (
     RelevanceRankAccuracy,
     TopKIntersection,
 )
-from tests.fixtures import *
 
 
 @pytest.fixture
@@ -297,36 +299,6 @@ def half_in_gt_2d_3ch():
     }
 
 
-# TODO: unused fixture
-@pytest.fixture
-def half_in_gt_zeros_bigger_1d_3ch():
-    s_batch = np.zeros((10, 1, 224))
-    a_batch = np.zeros((10, 1, 224))
-    s_batch[:, :, 0:100] = 1.0
-    a_batch[:, :, 0:100] = 1.0
-    return {
-        "x_batch": np.random.randn(10, 3, 224),
-        "y_batch": np.random.randint(0, 10, size=10),
-        "a_batch": a_batch,
-        "s_batch": s_batch,
-    }
-
-
-# TODO: unused fixture
-@pytest.fixture
-def half_in_gt_zeros_bigger_2d_3ch():
-    s_batch = np.zeros((10, 1, 224, 224))
-    a_batch = np.zeros((10, 1, 224, 224))
-    s_batch[:, :, 0:100, 0:100] = 1.0
-    a_batch[:, :, 0:100, 75:100] = 1.0
-    return {
-        "x_batch": np.random.randn(10, 3, 224, 224),
-        "y_batch": np.random.randint(0, 10, size=10),
-        "a_batch": a_batch,
-        "s_batch": s_batch,
-    }
-
-
 @pytest.fixture
 def load_artificial_attribution():
     """Build an artificial attribution map"""
@@ -359,24 +331,13 @@ def load_mnist_adaptive_lenet_model():
 
 
 @pytest.fixture
-def load_mnist_mosaics():
+def load_mnist_mosaics(load_mnist_images):
     """Load a batch of MNIST digits and build mosaics from them"""
-    x_batch = torch.as_tensor(
-        np.loadtxt("tests/assets/mnist_x").reshape(124, 1, 28, 28), dtype=torch.float,
-    ).numpy()
-    y_batch = torch.as_tensor(
-        np.loadtxt("tests/assets/mnist_y"), dtype=torch.int64
-    ).numpy()
-    mosaics_returns = mosaic_creation(
+    x_batch, y_batch = load_mnist_images["x_batch"], load_mnist_images["y_batch"]
+    all_mosaics, _, _, p_batch_list, target_list = mosaic_creation(
         images=x_batch, labels=y_batch, mosaics_per_class=10, seed=777
     )
-    (
-        all_mosaics,
-        mosaic_indices_list,
-        mosaic_labels_list,
-        p_batch_list,
-        target_list,
-    ) = mosaics_returns
+
     return {
         "x_batch": all_mosaics,
         "y_batch": target_list,
@@ -395,23 +356,12 @@ def load_cifar10_adaptive_lenet_model():
 
 
 @pytest.fixture
-def load_cifar10_mosaics():
+def load_cifar10_mosaics(load_cifar10_images):
     """Load a batch of Cifar10 and build mosaics from them"""
-    (x_train, y_train), (x_test, y_test) = cifar10.load_data()
-    x_batch = torch.as_tensor(
-        x_train[:124, ...].reshape(124, 3, 32, 32), dtype=torch.float,
-    ).numpy()
-    y_batch = torch.as_tensor(y_train[:124].reshape(124), dtype=torch.int64).numpy()
-    mosaics_returns = mosaic_creation(
+    x_batch, y_batch = load_cifar10_images["x_batch"], load_cifar10_images["y_batch"]
+    all_mosaics, _, _, p_batch_list, target_list = mosaic_creation(
         images=x_batch, labels=y_batch, mosaics_per_class=10, seed=777
     )
-    (
-        all_mosaics,
-        mosaic_indices_list,
-        mosaic_labels_list,
-        p_batch_list,
-        target_list,
-    ) = mosaics_returns
     return {
         "x_batch": all_mosaics,
         "y_batch": target_list,
@@ -426,21 +376,36 @@ def load_cifar10_mosaics():
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("all_in_gt_1d_3ch"),
-            {"init": {"disable_warnings": False, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
+            },
             True,
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("all_in_gt_2d_3ch"),
-            {"init": {"disable_warnings": False, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
+            },
             True,
         ),
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("all_in_gt_no_abatch_1d_1ch"),
             {
-                "init": {"disable_warnings": True, "display_progressbar": False,},
-                "call": {"explain_func": explain,},
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+                "call": {
+                    "explain_func": explain,
+                },
             },
             {"type": list},
         ),
@@ -448,51 +413,89 @@ def load_cifar10_mosaics():
             lazy_fixture("load_mnist_model"),
             lazy_fixture("all_in_gt_no_abatch_2d_1ch"),
             {
-                "init": {"disable_warnings": True, "display_progressbar": False,},
-                "call": {"explain_func": explain,},
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+                "call": {
+                    "explain_func": explain,
+                },
             },
             {"type": list},
         ),
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("none_in_gt_1d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+            },
             False,
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("none_in_gt_2d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+            },
             False,
         ),
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("half_in_gt_1d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+            },
             True,
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("half_in_gt_2d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+            },
             True,
         ),
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("all_in_gt_1d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": True,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": True,
+                },
+            },
             True,
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("all_in_gt_2d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": True,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": True,
+                },
+            },
             True,
         ),
     ],
 )
 def test_pointing_game(
-    model, data: dict, params: dict, expected: Union[bool, dict],
+    model,
+    data: dict,
+    params: dict,
+    expected: Union[bool, dict],
 ):
     init_params = params.get("init", {})
     call_params = params.get("call", {})
@@ -577,7 +580,9 @@ def test_pointing_game(
                     "disable_warnings": True,
                     "display_progressbar": False,
                 },
-                "call": {"explain_func": explain,},
+                "call": {
+                    "explain_func": explain,
+                },
             },
             {"type": list},
         ),
@@ -590,7 +595,9 @@ def test_pointing_game(
                     "disable_warnings": True,
                     "display_progressbar": False,
                 },
-                "call": {"explain_func": explain,},
+                "call": {
+                    "explain_func": explain,
+                },
             },
             {"type": list},
         ),
@@ -743,7 +750,10 @@ def test_pointing_game(
     ],
 )
 def test_top_k_intersection(
-    model, data: dict, params: dict, expected: Union[bool, dict],
+    model,
+    data: dict,
+    params: dict,
+    expected: Union[bool, dict],
 ):
     init_params = params.get("init", {})
     call_params = params.get("call", {})
@@ -773,21 +783,36 @@ def test_top_k_intersection(
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("all_in_gt_zeros_1d_3ch"),
-            {"init": {"disable_warnings": False, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
+            },
             1.0,
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("all_in_gt_zeros_2d_3ch"),
-            {"init": {"disable_warnings": False, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
+            },
             1.0,
         ),
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("all_in_gt_no_abatch_1d_1ch"),
             {
-                "init": {"disable_warnings": True, "display_progressbar": False,},
-                "call": {"explain_func": explain,},
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+                "call": {
+                    "explain_func": explain,
+                },
             },
             {"type": list},
         ),
@@ -795,63 +820,111 @@ def test_top_k_intersection(
             lazy_fixture("load_mnist_model"),
             lazy_fixture("all_in_gt_no_abatch_2d_1ch"),
             {
-                "init": {"disable_warnings": True, "display_progressbar": False,},
-                "call": {"explain_func": explain,},
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+                "call": {
+                    "explain_func": explain,
+                },
             },
             {"type": list},
         ),
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("all_in_gt_seg_bigger_1d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+            },
             {"min": 0.5, "max": 1.0},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("all_in_gt_seg_bigger_2d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+            },
             {"min": 0.5, "max": 1.0},
         ),
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("none_in_gt_zeros_1d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+            },
             0.0,
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("none_in_gt_zeros_2d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+            },
             0.0,
         ),
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("half_in_gt_zeros_1d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+            },
             0.5,
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("half_in_gt_zeros_2d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+            },
             0.5,
         ),
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("all_in_gt_zeros_1d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": True,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": True,
+                },
+            },
             1.0,
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("all_in_gt_zeros_2d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": True,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": True,
+                },
+            },
             1.0,
         ),
     ],
 )
 def test_relevance_mass_accuracy(
-    model, data: dict, params: dict, expected: Union[bool, dict],
+    model,
+    data: dict,
+    params: dict,
+    expected: Union[bool, dict],
 ):
     init_params = params.get("init", {})
     call_params = params.get("call", {})
@@ -885,21 +958,36 @@ def test_relevance_mass_accuracy(
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("all_in_gt_1d_3ch"),
-            {"init": {"disable_warnings": False, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
+            },
             1.0,
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("all_in_gt_2d_3ch"),
-            {"init": {"disable_warnings": False, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
+            },
             1.0,
         ),
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("all_in_gt_no_abatch_1d_1ch"),
             {
-                "init": {"disable_warnings": True, "display_progressbar": False,},
-                "call": {"explain_func": explain,},
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+                "call": {
+                    "explain_func": explain,
+                },
             },
             {"type": list},
         ),
@@ -907,21 +995,36 @@ def test_relevance_mass_accuracy(
             lazy_fixture("load_mnist_model"),
             lazy_fixture("all_in_gt_no_abatch_2d_1ch"),
             {
-                "init": {"disable_warnings": True, "display_progressbar": False,},
-                "call": {"explain_func": explain,},
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+                "call": {
+                    "explain_func": explain,
+                },
             },
             {"type": list},
         ),
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("all_in_gt_seg_bigger_1d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+            },
             {"min": 0.5, "max": 1.0},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("all_in_gt_seg_bigger_2d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+            },
             {"min": 0.5, "max": 1.0},
         ),
         (
@@ -951,31 +1054,54 @@ def test_relevance_mass_accuracy(
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("half_in_gt_1d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+            },
             {"min": 0.5, "max": 1.0},
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("half_in_gt_2d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+            },
             0.5,
         ),
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("all_in_gt_1d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": True,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": True,
+                },
+            },
             1.0,
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("all_in_gt_2d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": True,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": True,
+                },
+            },
             1.0,
         ),
     ],
 )
 def test_relevance_rank_accuracy(
-    model, data: dict, params: dict, expected: Union[bool, dict],
+    model,
+    data: dict,
+    params: dict,
+    expected: Union[bool, dict],
 ):
     init_params = params.get("init", {})
     call_params = params.get("call", {})
@@ -1013,21 +1139,36 @@ def test_relevance_rank_accuracy(
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("all_in_gt_1d_3ch"),
-            {"init": {"disable_warnings": False, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
+            },
             1.0,
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("all_in_gt_2d_3ch"),
-            {"init": {"disable_warnings": False, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
+            },
             1.0,
         ),
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("all_in_gt_no_abatch_1d_1ch"),
             {
-                "init": {"disable_warnings": True, "display_progressbar": False,},
-                "call": {"explain_func": explain,},
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+                "call": {
+                    "explain_func": explain,
+                },
             },
             {"type": list},
         ),
@@ -1035,8 +1176,13 @@ def test_relevance_rank_accuracy(
             lazy_fixture("load_mnist_model"),
             lazy_fixture("all_in_gt_no_abatch_2d_1ch"),
             {
-                "init": {"disable_warnings": True, "display_progressbar": False,},
-                "call": {"explain_func": explain,},
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+                "call": {
+                    "explain_func": explain,
+                },
             },
             {"type": list},
         ),
@@ -1067,31 +1213,54 @@ def test_relevance_rank_accuracy(
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("none_in_gt_fourth_1d"),
-            {"init": {"disable_warnings": True, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+            },
             0.0,  # TODO: verify correctness
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("none_in_gt_fourth_2d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": False,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": False,
+                },
+            },
             0.33333333333333337,  # TODO: verify correctness
         ),
         (
             lazy_fixture("load_1d_1ch_conv_model"),
             lazy_fixture("all_in_gt_1d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": True,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": True,
+                },
+            },
             1.0,
         ),
         (
             lazy_fixture("load_mnist_model"),
             lazy_fixture("all_in_gt_2d_3ch"),
-            {"init": {"disable_warnings": True, "display_progressbar": True,},},
+            {
+                "init": {
+                    "disable_warnings": True,
+                    "display_progressbar": True,
+                },
+            },
             1.0,
         ),
     ],
 )
 def test_auc(
-    model, data: dict, params: dict, expected: Union[bool, dict],
+    model,
+    data: dict,
+    params: dict,
+    expected: Union[bool, dict],
 ):
     init_params = params.get("init", {})
     call_params = params.get("call", {})
@@ -1150,7 +1319,9 @@ def test_auc(
                     "disable_warnings": True,
                     "display_progressbar": False,
                 },
-                "call": {"explain_func": explain,},
+                "call": {
+                    "explain_func": explain,
+                },
             },
             {"type": list},
         ),
@@ -1163,7 +1334,9 @@ def test_auc(
                     "disable_warnings": True,
                     "display_progressbar": False,
                 },
-                "call": {"explain_func": explain,},
+                "call": {
+                    "explain_func": explain,
+                },
             },
             {"type": list},
         ),
@@ -1268,7 +1441,10 @@ def test_auc(
     ],
 )
 def test_attribution_localisation(
-    model, data: dict, params: dict, expected: Union[bool, dict],
+    model,
+    data: dict,
+    params: dict,
+    expected: Union[bool, dict],
 ):
     init_params = params.get("init", {})
     call_params = params.get("call", {})
@@ -1300,10 +1476,15 @@ def test_attribution_localisation(
             lazy_fixture("load_mnist_mosaics"),
             None,
             {
-                "init": {"disable_warnings": False, "display_progressbar": False,},
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             None,
@@ -1313,10 +1494,15 @@ def test_attribution_localisation(
             lazy_fixture("load_mnist_mosaics"),
             None,
             {
-                "init": {"disable_warnings": False, "display_progressbar": False,},
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
                 },
             },
             None,
@@ -1326,10 +1512,15 @@ def test_attribution_localisation(
             lazy_fixture("load_mnist_mosaics"),
             None,
             {
-                "init": {"disable_warnings": False, "display_progressbar": False,},
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "GradientShap",},
+                    "explain_func_kwargs": {
+                        "method": "GradientShap",
+                    },
                 },
             },
             None,
@@ -1346,7 +1537,9 @@ def test_attribution_localisation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "IntegratedGradients",},
+                    "explain_func_kwargs": {
+                        "method": "IntegratedGradients",
+                    },
                 },
             },
             None,
@@ -1356,89 +1549,122 @@ def test_attribution_localisation(
             lazy_fixture("load_mnist_mosaics"),
             None,
             {
-                "init": {"disable_warnings": False, "display_progressbar": False,},
-                "call": {
-                    "explain_func": explain,
-                    "explain_func_kwargs": {"method": "InputXGradient",},
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
                 },
-            },
-            None,
-        ),
-        (
-            lazy_fixture("load_mnist_adaptive_lenet_model"),
-            lazy_fixture("load_mnist_mosaics"),
-            None,
-            {
-                "init": {"disable_warnings": False, "display_progressbar": False,},
-                "call": {
-                    "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
-                },
-            },
-            None,
-        ),
-        (
-            lazy_fixture("load_mnist_adaptive_lenet_model"),
-            lazy_fixture("load_mnist_mosaics"),
-            None,
-            {
-                "init": {"disable_warnings": False, "display_progressbar": False,},
-                "call": {
-                    "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
-                },
-            },
-            None,
-        ),
-        (
-            lazy_fixture("load_mnist_adaptive_lenet_model"),
-            lazy_fixture("load_mnist_mosaics"),
-            None,
-            {
-                "init": {"disable_warnings": False, "display_progressbar": False,},
-                "call": {
-                    "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
-                },
-            },
-            None,
-        ),
-        (
-            lazy_fixture("load_mnist_adaptive_lenet_model"),
-            lazy_fixture("load_mnist_mosaics"),
-            None,
-            {
-                "init": {"disable_warnings": False, "display_progressbar": False,},
-                "call": {
-                    "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
-                },
-            },
-            None,
-        ),
-        (
-            lazy_fixture("load_mnist_adaptive_lenet_model"),
-            lazy_fixture("load_mnist_mosaics"),
-            None,
-            {
-                "init": {"disable_warnings": False, "display_progressbar": False,},
-                "call": {
-                    "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Saliency",},
-                },
-            },
-            None,
-        ),
-        (
-            lazy_fixture("load_mnist_adaptive_lenet_model"),
-            lazy_fixture("load_mnist_mosaics"),
-            None,
-            {
-                "init": {"disable_warnings": False, "display_progressbar": False,},
                 "call": {
                     "explain_func": explain,
                     "explain_func_kwargs": {
-                        "method": "GradCam",
+                        "method": "InputXGradient",
+                    },
+                },
+            },
+            None,
+        ),
+        (
+            lazy_fixture("load_mnist_adaptive_lenet_model"),
+            lazy_fixture("load_mnist_mosaics"),
+            None,
+            {
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
+                "call": {
+                    "explain_func": explain,
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
+                },
+            },
+            None,
+        ),
+        (
+            lazy_fixture("load_mnist_adaptive_lenet_model"),
+            lazy_fixture("load_mnist_mosaics"),
+            None,
+            {
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
+                "call": {
+                    "explain_func": explain,
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
+                },
+            },
+            None,
+        ),
+        (
+            lazy_fixture("load_mnist_adaptive_lenet_model"),
+            lazy_fixture("load_mnist_mosaics"),
+            None,
+            {
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
+                "call": {
+                    "explain_func": explain,
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
+                },
+            },
+            None,
+        ),
+        (
+            lazy_fixture("load_mnist_adaptive_lenet_model"),
+            lazy_fixture("load_mnist_mosaics"),
+            None,
+            {
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
+                "call": {
+                    "explain_func": explain,
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
+                },
+            },
+            None,
+        ),
+        (
+            lazy_fixture("load_mnist_adaptive_lenet_model"),
+            lazy_fixture("load_mnist_mosaics"),
+            None,
+            {
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
+                "call": {
+                    "explain_func": explain,
+                    "explain_func_kwargs": {
+                        "method": "Saliency",
+                    },
+                },
+            },
+            None,
+        ),
+        (
+            lazy_fixture("load_mnist_adaptive_lenet_model"),
+            lazy_fixture("load_mnist_mosaics"),
+            None,
+            {
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
+                "call": {
+                    "explain_func": explain,
+                    "explain_func_kwargs": {
+                        "method": "LayerGradCam",
                         "gc_layer": "model._modules.get('conv_2')",
                         "interpolate": (56, 56),
                     },
@@ -1451,11 +1677,14 @@ def test_attribution_localisation(
             lazy_fixture("load_cifar10_mosaics"),
             None,
             {
-                "init": {"disable_warnings": False, "display_progressbar": False,},
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
                 "call": {
                     "explain_func": explain,
                     "explain_func_kwargs": {
-                        "method": "GradCam",
+                        "method": "LayerGradCam",
                         "gc_layer": "model._modules.get('conv_2')",
                         "interpolate": (64, 64),
                     },
@@ -1468,23 +1697,37 @@ def test_attribution_localisation(
             lazy_fixture("load_mnist_mosaics"),
             None,
             {
-                "init": {"disable_warnings": False, "display_progressbar": False,},
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Control Var. Sobel Filter",},
+                    "explain_func_kwargs": {
+                        "method": "Control Var. Sobel Filter",
+                    },
                 },
             },
             None,
         ),
         (
             lazy_fixture("load_mnist_adaptive_lenet_model"),
-            {"x_batch": None, "y_batch": None, "custom_batch": None,},
+            {
+                "x_batch": None,
+                "y_batch": None,
+                "custom_batch": None,
+            },
             None,
             {
-                "init": {"disable_warnings": False, "display_progressbar": False,},
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {"method": "Gradient",},
+                    "explain_func_kwargs": {
+                        "method": "Gradient",
+                    },
                 },
             },
             {"exception": ValueError},
@@ -1503,7 +1746,10 @@ def test_attribution_localisation(
             },
             lazy_fixture("load_artificial_attribution"),
             {
-                "init": {"disable_warnings": False, "display_progressbar": False,},
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
                 "call": {},
             },
             {"value": 1},
@@ -1522,7 +1768,10 @@ def test_attribution_localisation(
             },
             lazy_fixture("load_artificial_attribution"),
             {
-                "init": {"disable_warnings": False, "display_progressbar": False,},
+                "init": {
+                    "disable_warnings": False,
+                    "display_progressbar": False,
+                },
                 "call": {},
             },
             {"value": 0},
