@@ -1,5 +1,7 @@
 from typing import Union, Dict
 from pytest_lazyfixture import lazy_fixture
+import pytest
+import numpy as np
 
 from quantus.functions.explanation_func import explain
 from quantus.functions.discretise_func import floating_points, rank, sign, top_n_sign
@@ -11,7 +13,6 @@ from quantus.metrics.robustness import (
     LocalLipschitzEstimate,
     MaxSensitivity,
 )
-from tests.fixtures import *
 
 
 @pytest.mark.robustness
@@ -144,7 +145,7 @@ from tests.fixtures import *
                 "call": {
                     "explain_func": explain,
                     "explain_func_kwargs": {
-                        "method": "Gradient",
+                        "method": "VanillaGradients",
                     },
                 },
             },
